cheesecake.subprocess.ProcessError

Package cheesecake :: Module subprocess :: Class ProcessError |
[hide private]
[frames] | no frames]

## Class ProcessError
source code

    exceptions.Exception --+
                           |
                          ProcessError

This exception is raised when there is an error calling a subprocess.

Instance Methods | [hide private]
Inherited from `exceptions.Exception`: `__getitem__`, `__init__`, `__str__`